FlutterReadonlySignalUtils<T> extension
Signal extensions for watching value changes on BuildContext.
- on
Methods
-
unwatch(
BuildContext context) → void -
Available on ReadonlySignal<
Stop subscriptions to updates on a signal for watchers.T> , provided by the FlutterReadonlySignalUtils extension -
watch(
BuildContext context, {String? debugLabel}) → T -
Available on ReadonlySignal<
Rebuild the Element that the current signal is inside of.T> , provided by the FlutterReadonlySignalUtils extension