MultiSignalProvider class
A dependency-injection / state propagation widget that allows passing multiple reactive signals down the Flutter widget tree.
This avoids the deeply nested trees that result from nesting multiple single SignalProvider widgets.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- MultiSignalProvider
- Available extensions
Constructors
-
MultiSignalProvider({Key? key, required List<
SignalProvider< providers, required Widget child})FlutterReadonlySignal> > -
Exposes multiple SignalProvider widgets inside a flat list.
const
Properties
- child → Widget
-
The widget subtree that will have access to the provided signals.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
providers
→ List<
SignalProvider< FlutterReadonlySignal> > -
The list of single SignalProvider widgets to nest.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toSignalWidget(
) → SignalWidget -
Available on StatelessWidget, provided by the StatelessWidgetConvertWidgetExtension extension
Converts this StatelessWidget to a SignalWidget. -
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited