SignalBuilder class
A premium, surgical builder widget that rebuilds locally on signal changes.
SignalBuilder tracks any signals read dynamically within its builder callback and
automatically subscribes to them. When any of these signals update, only the SignalBuilder
is rebuilt, preventing costly rebuilds of the surrounding widget subtree.
This widget provides predictable, immediate, and memory-safe subscription management, automatically tearing down all active signal subscriptions when the builder is unmounted.
Surgical Counter Example
final count = signal(0);
class CounterPage extends StatelessWidget {
const CounterPage({super.key});
@override
Widget build(BuildContext context) {
return Scaffold(
appBar: AppBar(title: const Text('Counter')),
body: Center(
child: Column(
mainAxisAlignment: MainAxisAlignment.center,
children: [
const Text('This static text never rebuilds!'),
const SizedBox(height: 20),
// Only this specific Text widget rebuilds when 'count' changes:
SignalBuilder(
builder: (context) => Text(
'Count: ${count.value}',
style: Theme.of(context).textTheme.headlineMedium,
),
),
],
),
),
floatingActionButton: FloatingActionButton(
onPressed: () => count.value++,
child: const Icon(Icons.add),
),
);
}
}
Tip
Keep SignalBuilder widgets as small and leaf-level as possible in your tree to maximize
rendering performance.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SignalWidget
- SignalBuilder
- Available extensions
Constructors
-
SignalBuilder({Key? key, required Widget builder(BuildContext context), List<
ReadonlySignal> dependencies = const []}) -
Creates a SignalBuilder widget.
const
Properties
- builder → Widget Function(BuildContext context)
-
The widget to rebuild when any signals change.
final
-
dependencies
→ List<
ReadonlySignal> -
List of optional dependencies to watch.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toSignalWidget(
) → SignalWidget -
Available on StatelessWidget, provided by the StatelessWidgetConvertWidgetExtension extension
Converts this StatelessWidget to a SignalWidget. -
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited