SignalBuilder constructor

const SignalBuilder({
  1. Key? key,
  2. required Widget builder(
    1. BuildContext context
    ),
  3. List<ReadonlySignal> dependencies = const [],
})

Creates a SignalBuilder widget.

The builder is called to construct the widget tree and tracks read signals. The optional dependencies allows explicitly specifying a list of signals to watch regardless of whether they are read during the build phase.

Implementation

const SignalBuilder({
  super.key,
  required this.builder,
  this.dependencies = const [],
});