shouldRepaint abstract method
Return true if the painter should be updated when the widget configuration changes.
Implementation
bool shouldRepaint(covariant SignalCustomPainter oldDelegate);
Return true if the painter should be updated when the widget configuration changes.
bool shouldRepaint(covariant SignalCustomPainter oldDelegate);