effect property
dynamic Function(BuildContext context)
get
effect
Gets the effect callback to run inside the reactive effect.
Implementation
dynamic Function(BuildContext context) get effect => _effect!;
Gets the effect callback to run inside the reactive effect.
dynamic Function(BuildContext context) get effect => _effect!;