WatchBuilder<T extends Widget> class
WatchBuilder
To watch a signal for changes in Flutter, use the WatchBuilder widget. This will only rebuild this widget method and not the entire widget tree.
final signal = signal(10);
...
@override
Widget build(BuildContext context) {
return WatchBuilder(
child: const Icon(Icons.add),
builder: (context, child) => Row(children: [Text('$signal'), child!]),
);
}
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- WatchBuilder
- Available extensions
- Annotations
-
- @Deprecated('Use SignalAnimatedBuilder instead for superior reactivity and consistent naming.')
Constructors
-
WatchBuilder({Key? key, required T builder(BuildContext context, Widget? child), String? debugLabel, List<
ReadonlySignal> dependencies = const [], Widget? child}) -
Minimal builder for signal changes that rerender a widget tree.
const
Properties
- builder → T Function(BuildContext context, Widget? child)
-
The widget to rebuild when any signals change
final
- child → Widget?
-
Cached widget to pass in
final
- debugLabel → String?
-
Optional debug label to use for devtools
final
-
dependencies
→ List<
ReadonlySignal> -
List of optional dependencies to watch
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toSignalWidget(
) → SignalWidget -
Available on StatelessWidget, provided by the StatelessWidgetConvertWidgetExtension extension
Converts this StatelessWidget to a SignalWidget. -
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited