TickerSignal class
Ticker signal used to drive animations and can create animation controllers
void main() {
final ticker = TickerSignal(); // could be a global
final controller = ticker.toAnimationController(); // can be local or global
final curve = CurvedAnimation(parent: controller, curve: Curves.easeOut); // can be used outside of widget tree
final alpha = IntTween(begin: 0, end: 255).animate(curve);
...
final alphaSignal = alpha.toSignal(); // can be converted to a signal
}
- Inheritance
- Implemented types
Constructors
-
TickerSignal({Duration? initialDuration, SignalOptions<
Duration> ? options, @Deprecated('Use options: SignalOptions(name: ...) instead') String? debugLabel}) - Ticker signal used to drive animations and can create animation controllers
Properties
- autoDispose ↔ bool
-
Throws and error if read after dispose and can be
disposed on last unsubscribe.
getter/setter pairinherited
- debugLabel → String?
-
Debug label for Debug Mode
Debug label for Debug Mode
no setterinherited
- disposed ↔ bool
-
Check if the effect is disposed
getter/setter pairinherited
-
equalityCheck
→ SignalEquality<
Duration> -
Optional method to check if to values are the same
no setterinherited
- globalId → int
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalValue → Duration
-
@internal
Internal getter for the raw value without subscription tracking.
no setterinherited
- isInitialized → bool
-
Check if a signal value is set (does not subscribe)
no setterinherited
- name → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unwatched → void Function()?
-
finalinherited
- value ↔ Duration
-
Gets the current value of the signal.
getter/setter pairinherited
- version ↔ int
-
Version numbers should always be >= 0, because the special value -1 is used
by Nodes to signify potentially unused but recyclable nodes.
getter/setter pairinherited
- watched → void Function()?
-
finalinherited
Methods
-
call(
) → Duration -
Return the value when invoked
inherited
-
createTicker(
TickerCallback onTick) → Ticker -
Creates a ticker with the given callback.
override
-
dispose(
) → void -
Dispose the signal
override
-
get(
) → Duration -
Helper method to get the current value
inherited
-
internalRefresh(
) → bool -
@internal
Refreshes the signal's value internally.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
void cleanup()) → void Function() -
Add a cleanup function to be called when the signal is disposed
inherited
-
overrideWith(
Duration val) → Signal< Duration> -
Override the current signal with a new value as if it was created with it.
inherited
-
peek(
) → Duration -
In the rare instance that you have an effect that should write to another signal based on the previous value, but you don't want the effect to be subscribed to that signal, you can read a signals's previous value via
signal.peek().inherited -
readonly(
) → ReadonlySignal< Duration> -
Returns a readonly signal
inherited
-
set(
Duration val, {bool force = false}) → bool -
Updates the signal's value by method call.
inherited
-
subscribe(
void fn(Duration value)) → void Function() -
Subscribe to value changes with a dispose function
inherited
-
subscribeToNode(
Node node) → void -
@internal
Subscribes this signal to notifications from a given dependency
node.inherited -
toAnimationController(
{double? value, Duration? duration, Duration? reverseDuration, String? debugLabel, double lowerBound = 0.0, double upperBound = 1.0, AnimationBehavior animationBehavior = AnimationBehavior.normal}) → AnimationController - Create a new AnimationController
-
toJson(
) → dynamic -
Convert value to JSON
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribeFromNode(
Node node) → void -
@internal
Unsubscribes this signal from notifications from a given dependency
node.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited